<?php
/**
 * Sample implementation of the Custom Header feature
 *
 * You can add an optional custom header image to header.php like so ...
 *
	<?php the_header_image_tag(); ?>
 *
 * @link https://developer.wordpress.org/themes/functionality/custom-headers/
 *
 * @package intechno
 */

/**
 * Set up the WordPress core custom header feature.
 *
 * @uses intechno_header_style()
 */
if (!function_exists('intechno_custom_header_setup')) :
    function intechno_custom_header_setup()
    {
        add_theme_support('custom-header', apply_filters('intechno_custom_header_args', array(
            'default-image'      => '',
            'default-text-color' => '212121',
            'width'              => 1000,
            'height'             => 250,
            'flex-height'        => true,
            'wp-head-callback'   => 'intechno_header_style',
        )));
    }
    add_action( 'after_setup_theme', 'intechno_custom_header_setup' );
endif;

if ( !function_exists('intechno_header_style') ) :
    /**
     * Styles the header image and text displayed on the blog.
     *
     * @see intechno_custom_header_setup().
     */
    function intechno_header_style()
    {
        $header_text_color = get_header_textcolor();
        $header_image      = get_header_image();
        
        $custom_css = "";
        
        if ( ! display_header_text() ) {
            $custom_css .= "
                .navbar-brand .site-title,.navbar-brand .site-title:hover {
                color: rgba(241, 241, 241, 0);
                position:absolute;
                clip: rect(1px 1px 1px 1px);
                }
                .site-description{
                color: rgba(241, 241, 241, 0);
                position:absolute;
                clip: rect(1px 1px 1px 1px);
                }";
        } else {
            $custom_css .= ".navbar-brand .site-title,
            .site-description{
                color: #".esc_attr( $header_text_color ).";
            }";
        } 
        if ( has_header_image() ) { 
            $custom_css .= ".bg-banner {
                background-image: url(".$header_image.");
                background-size:cover;
                }
                .bg-banner
                {
                    margin-bottom: 100px;
                }
                .banner-box h2,.breadcrumb-item,.breadcrumb-item+.breadcrumb-item::before{
                    color:#f5f5f5;
                }
                .breadcrumb-item.active{
                    color:#ccc;
                }
            ";
        } 

        // If we get this far, we have custom styles. Let's do this.
        wp_enqueue_style(
            'intechno-custom-header-style1',
            get_template_directory_uri() . '/assets/css/custom-header-style.css'
        );
        wp_add_inline_style( 'intechno-custom-header-style1', $custom_css ); 
        ?>
    <?php
    }
endif;