<?php
/**
 * intechno Theme Customizer
 *
 * @package intechno
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function intechno_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial(
			'blogname',
			array(
				'selector'        => '.site-title a',
				'render_callback' => 'intechno_customize_partial_blogname',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'blogdescription',
			array(
				'selector'        => '.site-description',
				'render_callback' => 'intechno_customize_partial_blogdescription',
			)
		);
	}
}
add_action( 'customize_register', 'intechno_customize_register' );

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function intechno_customize_partial_blogname() {
	bloginfo( 'name' );
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function intechno_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function intechno_customize_preview_js() {
	wp_enqueue_script( 'intechno-customizer', get_template_directory_uri() . '/js/customizer.js', array( 'customize-preview' ), '', true );
}
add_action( 'customize_preview_init', 'intechno_customize_preview_js' );

/***
    *** Register Customizer Add Panel Function Code start Here
***/
function intechno_Customizer_Add_Panel_Function( $wp_customize ) {

	// Create Custom Aanel for Home Page.
	$wp_customize->add_panel( 'intechno_Panel_Function', array(
		'theme_supports' => '',
		'title'          => __( ' Intechno Theme Options ', 'intechno' ),
		'priority' => 1,
	) ); 
}
add_action( 'customize_register', 'intechno_Customizer_Add_Panel_Function' );
/***
    *** Register Customizer Add Panel Function Code END Here
***/

/***
    *** Register Customizer Home Banner Section Code start Here
***/
class intechno_Banner_Customizer {

	public static function intechno__Banner_Section( $wp_customize ) {

		// Add Home Banner Section Add Section for home page.
		$wp_customize->add_section( 'intechno_For_Home_Page_Banner_Section' , array(
			'title'    => __(' Home Banner Section ','intechno'),
			'panel'    => 'intechno_Panel_Function',
			'priority' => 1,
		) );

		//  ============================================================
	    //       Home Page Banner Section Image Upload         
	    //  ============================================================
	    $wp_customize->add_setting( 'intechno_Banner_Section_Image_Upload', array( 'sanitize_callback' => 'Home_Banner_Section_Sanitize_Text_Function',
	    )); 
	        	   
	    $wp_customize->add_control( new WP_Customize_Image_Control( 
	    	$wp_customize, 'intechno_Home_Banner_Section_Image_Upload_Id', array(
	        'label'    => ' Banner Image ',
	        'priority' => 1,
	        'section'  => 'intechno_For_Home_Page_Banner_Section',
	        'settings' => 'intechno_Banner_Section_Image_Upload',
	        'button_labels' => array(
	                    // All These labels are optional
	                    'select' => __( 'Select Image', 'intechno' ),
	                    'remove' => __( 'Remove Image', 'intechno' ),
	                    'change' => __( 'Change Image', 'intechno' )
	                    )
	    )));

		//  ============================================================
	    //       Home Page Banner Section Section Title        
	    //  ============================================================
		$wp_customize->add_setting( 'intechno_Banner_Section_Title_Name', array(
			'sanitize_callback' => 'Home_Banner_Section_Sanitize_Text_Function',
			
		) );

		// Add Banner Title Add control
		$wp_customize->add_control( new WP_Customize_Control(
		    $wp_customize,
			'intechno_Home_Banner_Section_ID',
			    array(
			        'label'    => __( ' Banner Title ', 'intechno' ),
			        'section'  => 'intechno_For_Home_Page_Banner_Section',
			        'settings' => 'intechno_Banner_Section_Title_Name',
			        'type'     => 'text',
			        'priority' => 2,
			    )
		    )
		);

		//  ============================================================
	    //       Home Page Banner Section Content        
	    //  ============================================================
		$wp_customize->add_setting( 'intechno_Banner_Section_Content_Textarea', array(
			'sanitize_callback' => 'Home_Banner_Section_Sanitize_Text_Function',
			
		) );

		// Add Banner Content Add control
		$wp_customize->add_control( new WP_Customize_Control(
		    $wp_customize,
			'intechno_Banner_Section_Main_Content',
			    array(
			        'label'    => __( ' Banner Content ', 'intechno' ),
			        'section'  => 'intechno_For_Home_Page_Banner_Section',
			        'settings' => 'intechno_Banner_Section_Content_Textarea',
			        'type'     => 'textarea',
			        'priority' => 3,
			    )
		    )
		);

		//  ============================================================
	    //       Home Page Banner Section Button Text         
	    //  ============================================================
		$wp_customize->add_setting( 'intechno_Banner_Section_Button_Text', array(
			 'sanitize_callback' => 'Home_Banner_Section_Sanitize_Text_Function',
			 
		) );

		// Button Text Add control
		$wp_customize->add_control( new WP_Customize_Control(
		    $wp_customize,
			'intechno_Home_Banner_Section_Button_Text',
			    array(
			        'label'    => __( ' Button Text ', 'intechno' ),
			        'section'  => 'intechno_For_Home_Page_Banner_Section',
			        'settings' => 'intechno_Banner_Section_Button_Text',
			        'type'     => 'text',
			        'priority' => 4,
			    )
		    )
		);

		//  ============================================================
	    //       Home Page Banner Section Button Url Path          
	    //  ============================================================
		$wp_customize->add_setting( 'intechno_Banner_Btn_URl_Path', array(
			 'sanitize_callback' => 'Home_Banner_Section_Sanitize_Text_Function',
			 
		) );

		// Add Button Url Path Add control
		$wp_customize->add_control( new WP_Customize_Control(
		    $wp_customize,
			'intechno_Custom_Button_URl_Path',
			    array(
			        'label'    => __( ' Button Url ', 'intechno' ),
			        'section'  => 'intechno_For_Home_Page_Banner_Section',
			        'settings' => 'intechno_Banner_Btn_URl_Path',
			        'type'     => 'text',
			        'priority' => 5,
			    )
		    )
		);

	    // Sanitize Text Function For Home Banner
		function Home_Banner_Section_Sanitize_Text_Function( $text ) {
		    return sanitize_text_field( $text );
		}
	}
}
add_action( 'customize_register', array('intechno_Banner_Customizer', 'intechno__Banner_Section') );
/***
    *** Register Customizer Home Banner Section Code END Here
***/


/***
    *** Register Customizer Blog Section Code start Here
***/
class intechno_Blog_Customizer {

	public static function intechno_Blog_section( $wp_customize ) {

		// Add Blog Section
		$wp_customize->add_section( 'intechno__for_Blog_section' , array(
			'title'    => __(' Blog Section ','intechno'),
			'panel' => 'intechno_Panel_Function',
		) );

		/*******************************************************************************
		                    Blog Section Title Text Code 
		********************************************************************************/
		$wp_customize->add_setting( 'intechno_Blog_Section_Title', array(
	       'sanitize_callback' => 'intechno_Blog_Section_Page_Sanitize_Text',
		) );

		// Add Blog Section Title Add control
		$wp_customize->add_control( new WP_Customize_Control(
		    $wp_customize,
			'intechno_Blog_Section_ID',
			    array(
			        'label'    => __( ' Blog Section Title ', 'intechno' ),
			        'section'  => 'intechno__for_Blog_section',
			        'settings' => 'intechno_Blog_Section_Title',
			        'type'     => 'text',
			        'priority' => 1,
			    )
		    )
		);

		/*******************************************************************************
		                    Blog Section Title Description Code 
		********************************************************************************/
		$wp_customize->add_setting( 'intechno_Blog_Section_Description', array(
	       'sanitize_callback' => 'intechno_Blog_Section_Page_Sanitize_Text',
		) );

		// Add Blog Section Description Add control
		$wp_customize->add_control( new WP_Customize_Control(
		    $wp_customize,
			'intechno_Blog_Section_Description_Id',
			    array(
			        'label'    => __( ' Blog Section Description ', 'intechno' ),
			        'section'  => 'intechno__for_Blog_section',
			        'settings' => 'intechno_Blog_Section_Description',
			        'type'     => 'textarea',
			        'priority' => 2,
			    )
		    )
		);

	    // Sanitize Text Function For Home Blog  Section
		function intechno_Blog_Section_Page_Sanitize_Text( $text ) {
		    return sanitize_text_field( $text );
		}	
	}
}
add_action( 'customize_register', array('intechno_Blog_Customizer', 'intechno_Blog_section') );
/***
    *** Register Customizer Blog Section Code End Here
***/